@@ -88,7 +88,7 @@ class Incantation:
     def create(self):
         if self.is_deployed:
             raise Exception('This incantation has already been deployed: ' + self.incantation_id)
-        url = self.BASE_URL + 'incantations'
+        url = BASE_URL + 'incantations'
         payload = {
             'title': self.title,
             'text': self.text,
@@ -104,7 +104,7 @@ class Incantation:
     def update(self):
         if not self.is_deployed:
             raise Exception('This incantation has not been deployed yet. Please run `incantation.create()` before running `incantation.update()')
-        url = self.BASE_URL + f'incantations/{self.incantation_id}'
+        url = BASE_URL + f'incantations/{self.incantation_id}'
         payload = {}
         if self.title is not None:
             payload['title'] = self.title
@@ -118,14 +118,14 @@ class Incantation:
         return resp['body']
 
     def delete(self, incantation_id: str):
-        url = self.BASE_URL + f'incantations/{incantation_id}'
+        url = BASE_URL + f'incantations/{incantation_id}'
         _format_http_response(requests.delete(url, headers=HEADERS))
         del incantations[incantation_id]
 
 
 class Model:
     def __init__(self, model_spec: dict, supp_id: str = None, description: str = None, model_id: str = None):
-        self.model_instances = self.get_model_instances()
+        self.model_instances = self.get_instances()
         self.model_id = model_id
         self.model_spec = model_spec
         self.supp_id = supp_id
@@ -135,7 +135,7 @@ class Model:
     def create(self):
         if self.is_deployed:
             raise Exception('This model has already been deployed: ' + self.model_id)
-        url = self.BASE_URL + 'models'
+        url = BASE_URL + 'models'
         payload = {
             'model_spec': self.model_spec,
             'supp_id': self.supp_id,
@@ -150,7 +150,7 @@ class Model:
     def update(self):
         if not self.is_deployed:
             raise Exception('This model has not been deployed yet. Please run `model.create()` before running `model.update()')
-        url = self.BASE_URL + f'models/{self.model_id}'
+        url = BASE_URL + f'models/{self.model_id}'
         payload = {}
         if self.model_spec is not None:
             payload['model_spec'] = self.model_spec
@@ -162,13 +162,13 @@ class Model:
         return resp['body']
 
     def delete(self):
-        url = self.BASE_URL + f'models/{self.model_id}'
+        url = BASE_URL + f'models/{self.model_id}'
         _format_http_response(requests.delete(url, headers=HEADERS))
         del models[self.model_id]
         return True
 
     def get_instances(self):
-        url = self.BASE_URL + f'models/{self.model_id}/instances'
+        url = BASE_URL + f'models/{self.model_id}/instances'
         resp = _format_http_response(requests.get(url, headers=HEADERS))
         instances = {}
         for instance in resp['body']:
@@ -193,7 +193,7 @@ class ModelInstance:
 
     def get_chat_history(self):
         # get chat history interactions with pagination
-        url = self.BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}/chat_history'
+        url = BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}/chat_history'
         response = _format_http_response(requests.get(url, headers=HEADERS))
         self.chat_history.extend(response['body']['interactions'])
         while 'next_page_token' in response:
@@ -203,7 +203,7 @@ class ModelInstance:
     def create(self):
         if self.is_deployed:
             raise Exception('This model instance has already been deployed: ' + self.instance_id)
-        url = self.BASE_URL + f'models/{self.model_id}/instances'
+        url = BASE_URL + f'models/{self.model_id}/instances'
         payload = {
             'supp_id': self.supp_id,
             'description': self.description
@@ -217,7 +217,7 @@ class ModelInstance:
     def update(self):
         if not self.is_deployed:
             raise Exception('This model instance has not been deployed yet. Please run `model_instance.create()` before running `model_instance.update()')
-        url = self.BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}'
+        url = BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}'
         payload = {}
         if self.supp_id is not None:
             payload['supp_id'] = self.supp_id
@@ -227,13 +227,13 @@ class ModelInstance:
         return resp['body']
 
     def delete(self):
-        url = self.BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}'
+        url = BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}'
         resp = _format_http_response(requests.delete(url, headers=HEADERS))
         del models[self.instance_id]
         return resp['body']
 
     def get_response(self, human_input: list):
-        url = self.BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}/get_response'
+        url = BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}/get_response'
         payload = {
             'human_input': human_input
         }
